# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/api/account.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nf.pb.core.api import common_pb2 as core_dot_api_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from nf.pb.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core/api/account.proto',
  package='core.api',
  syntax='proto3',
  serialized_pb=_b('\n\x16\x63ore/api/account.proto\x12\x08\x63ore.api\x1a\x15\x63ore/api/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x14gogoproto/gogo.proto\"V\n\x13RequestCommonParams\x12\x12\n\nuser_token\x18\x01 \x01(\t\x12\x0b\n\x03mac\x18\x04 \x01(\t\x12\n\n\x02ip\x18\x05 \x01(\t\x12\x12\n\nop_station\x18\x06 \x01(\t\"\xab\x07\n\x05Order\x12\x0f\n\x07\x61pi_key\x18! \x01(\t\x12\x12\n\napi_secret\x18\" \x01(\t\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x03 \x01(\t\x12\x11\n\tcl_ord_id\x18\x04 \x01(\t\x12\x10\n\x08order_id\x18\x05 \x01(\t\x12\x11\n\tex_ord_id\x18\x06 \x01(\t\x12\x0e\n\x06symbol\x18\x07 \x01(\t\x12!\n\x04side\x18\x08 \x01(\x0e\x32\x13.core.api.OrderSide\x12\'\n\x07subject\x18% \x01(\x0e\x32\x16.core.api.SecurityType\x12\x10\n\x08password\x18\t \x01(\t\x12\'\n\norder_type\x18\x0b \x01(\x0e\x32\x13.core.api.OrderType\x12%\n\torder_src\x18\x0e \x01(\x0e\x32\x12.core.api.OrderSrc\x12%\n\x06status\x18\x0f \x01(\x0e\x32\x15.core.api.OrderStatus\x12\x1d\n\x15ord_rej_reason_detail\x18\x11 \x01(\t\x12\r\n\x05price\x18\x12 \x01(\x01\x12\x12\n\nstop_price\x18\x13 \x01(\x01\x12\x11\n\texec_inst\x18\' \x01(\t\x12\x0e\n\x06volume\x18\x15 \x01(\x01\x12\r\n\x05value\x18\x16 \x01(\x01\x12\x15\n\rfilled_volume\x18\x1b \x01(\x01\x12\x13\n\x0b\x66illed_vwap\x18\x1c \x01(\x01\x12\x15\n\rfilled_amount\x18\x1d \x01(\x01\x12\x19\n\x11\x66illed_commission\x18  \x01(\x01\x12\x19\n\x11\x66illed_commi_coin\x18# \x01(\t\x12\x1b\n\x13\x66illed_commi_volume\x18$ \x01(\x01\x12#\n\nmodel_type\x18( \x01(\x0e\x32\x0f.core.api.Model\x12\x10\n\x08leverage\x18) \x01(\x01\x12\x12\n\ndisplayQty\x18+ \x01(\x05\x12\x15\n\rtime_in_force\x18, \x01(\t\x12\x34\n\ncreated_at\x18\x1e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x34\n\nupdated_at\x18\x1f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x12\n\nsymbol_old\x18- \x01(\t\x12\x35\n\x0bsettle_time\x18. \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"\x90\x01\n\x06Orders\x12\x1d\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x0f.core.api.Order\x12\x34\n\nproperties\x18\x03 \x03(\x0b\x32 .core.api.Orders.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x0bOrdersPaged\x12\x1e\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x10.core.api.Orders\"\x8e\x05\n\x07\x45xecRpt\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x03 \x01(\t\x12\x11\n\tcl_ord_id\x18\x04 \x01(\t\x12\x10\n\x08order_id\x18\x05 \x01(\t\x12\x11\n\tex_ord_id\x18\x06 \x01(\t\x12\x0f\n\x07\x65xec_id\x18\x07 \x01(\t\x12\x0e\n\x06symbol\x18\x08 \x01(\t\x12!\n\x04side\x18\x0b \x01(\x0e\x32\x13.core.api.OrderSide\x12\x1d\n\x15ord_rej_reason_detail\x18\r \x01(\t\x12%\n\texec_type\x18\x0e \x01(\x0e\x32\x12.core.api.ExecType\x12\r\n\x05price\x18\x0f \x01(\x01\x12\x0e\n\x06volume\x18\x10 \x01(\x01\x12\x0e\n\x06\x61mount\x18\x11 \x01(\x01\x12%\n\torder_src\x18\x15 \x01(\x0e\x32\x12.core.api.OrderSrc\x12\x34\n\ncreated_at\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x16\n\x0eoriginal_price\x18\x16 \x01(\x01\x12\x17\n\x0foriginal_volume\x18\x17 \x01(\x01\x12\x10\n\x08\x65xecinst\x18\x18 \x01(\t\x12\x10\n\x08\x63urrency\x18\x19 \x01(\t\x12\x13\n\x0bliquidation\x18\x1a \x01(\x08\x12\x0c\n\x04text\x18\x1b \x01(\t\x12\'\n\x07subject\x18\x1c \x01(\x0e\x32\x16.core.api.SecurityType\x12$\n\x07ordType\x18\x1d \x01(\x0e\x32\x13.core.api.OrderType\x12\x0c\n\x04\x62\x61se\x18\x1e \x01(\t\x12\r\n\x05quote\x18\x1f \x01(\t\x12\x12\n\nstop_price\x18  \x01(\x01\"+\n\x08\x45xecRpts\x12\x1f\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x11.core.api.ExecRpt\"\xd1\x01\n\x04\x43\x61sh\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x10\n\x08\x63urrency\x18\x03 \x01(\t\x12\x0e\n\x06\x66rozen\x18\x07 \x01(\x01\x12\x11\n\tavailable\x18\t \x01(\x01\x12\x34\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x34\n\nupdated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"&\n\x06\x43\x61shes\x12\x1c\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x0e.core.api.Cash\"\xc7\x08\n\x08Position\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0c\n\x04side\x18\x06 \x01(\x05\x12\x0e\n\x06\x66rozen\x18\x07 \x01(\x01\x12\x11\n\tavailable\x18\t \x01(\x01\x12\x0c\n\x04\x63\x61sh\x18\n \x01(\x01\x12\x10\n\x08pop_rate\x18\x0b \x01(\x01\x12\x0e\n\x06symbol\x18\x0c \x01(\t\x12\x0c\n\x04\x62\x61se\x18\r \x01(\t\x12\r\n\x05quote\x18\x0e \x01(\t\x12\'\n\x07subject\x18\x0f \x01(\x0e\x32\x16.core.api.SecurityType\x12\x0e\n\x06\x61mount\x18\x10 \x01(\x01\x12\r\n\x05value\x18\x11 \x01(\x01\x12\r\n\x05price\x18\x12 \x01(\x01\x12\x12\n\nmark_price\x18\x13 \x01(\x01\x12\x34\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x34\n\nupdated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x33\n\tsettle_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x17\n\x0fmaintain_margin\x18\x17 \x01(\x01\x12\x13\n\x0bmargin_rate\x18\x18 \x01(\x01\x12#\n\nmodel_type\x18\x19 \x01(\x0e\x32\x0f.core.api.Model\x12\x1a\n\x12\x63urrent_commission\x18\x1a \x01(\x01\x12\x17\n\x0fmargin_currency\x18\x1b \x01(\t\x12\x12\n\nalert_rate\x18\x1c \x01(\x01\x12\x18\n\x10\x63onfirmed_profit\x18\x1d \x01(\x01\x12$\n\x1cunconfirmed_profit_markprice\x18\x1e \x01(\x01\x12\x1a\n\x12unconfirmed_profit\x18\x1f \x01(\x01\x12\x10\n\x08leverage\x18  \x01(\x01\x12\x35\n\x0bsettle_time\x18! \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x19\n\x11liquidation_price\x18\" \x01(\x01\x12\x16\n\x0e\x62\x61nkrupt_price\x18# \x01(\x01\x12\x18\n\x10init_margin_rate\x18$ \x01(\x01\x12\x15\n\ravgEntryPrice\x18% \x01(\x01\x12\x0e\n\x06margin\x18& \x01(\x01\x12\x11\n\tpos_state\x18\' \x01(\t\x12\x12\n\nsymbol_old\x18( \x01(\t\x12\x12\n\ncan_reduce\x18) \x01(\x01\x12\x11\n\tclose_tfv\x18* \x01(\x01\x12\x16\n\x0e\x66illed_balance\x18+ \x01(\x01\x12\x0e\n\x06profit\x18, \x01(\x01\x12\x15\n\rpft_close_tfv\x18- \x01(\x01\x12\x15\n\rreal_leverage\x18. \x01(\x01\x12\x1c\n\x14liquidation_price_rl\x18/ \x01(\x01\"k\n\nSettlement\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x15\n\rsettled_price\x18\x02 \x01(\x01\x12\x36\n\x0csettled_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"5\n\x0fSettlementItems\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.core.api.Settlement\"\x86\x01\n\x04Stat\x12\x17\n\x0funderlying_base\x18\x01 \x01(\t\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12\x14\n\x0cturnover_24h\x18\x03 \x01(\x01\x12\x12\n\nvolume_24h\x18\x04 \x01(\x01\x12\x15\n\ropen_interest\x18\x05 \x01(\x01\x12\x12\n\nopen_value\x18\x06 \x01(\x01\")\n\tStatItems\x12\x1c\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x0e.core.api.Stat\"\xc1\x01\n\x05\x41sset\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\x12\x16\n\x0emargin_balance\x18\x02 \x01(\x01\x12\x19\n\x11\x61vailable_balance\x18\x03 \x01(\x01\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x14\n\x0crealised_pnl\x18\x05 \x01(\x01\x12\x16\n\x0eunrealised_pnl\x18\x06 \x01(\x01\x12\x0e\n\x06margin\x18\x07 \x01(\x01\x12\x14\n\x0corder_margin\x18\x08 \x01(\x01\x12\x10\n\x08\x65xchange\x18\t \x01(\t\"-\n\x0cMarginAssets\x12\x1d\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x0f.core.api.Asset\";\n\x13GetMarginAssetsResp\x12$\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x16.core.api.MarginAssets\"G\n\nCommission\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\x12\x18\n\x10\x63ommission_ratio\x18\x03 \x01(\x01\"-\n\tPositions\x12 \n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x12.core.api.Position\"\xe0\x02\n\x07\x41\x63\x63ount\x12!\n\naccount_id\x18\x01 \x01(\tB\r\xf2\xde\x1f\txorm:\"pk\"\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x05 \x01(\t\x12\x12\n\nsecret_key\x18\x06 \x01(\t\x12\x10\n\x08password\x18\x07 \x01(\t\x12\x46\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"created\"\x12\x46\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"updated\"\x12\x0f\n\x07user_id\x18\n \x01(\t\x12+\n\x0c\x61\x63\x63ount_type\x18\x0b \x01(\x0e\x32\x15.core.api.AccountType\"+\n\x08\x41\x63\x63ounts\x12\x1f\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x11.core.api.Account\"O\n\rAccountStatus\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12*\n\x06status\x18\x03 \x01(\x0b\x32\x1a.core.api.ConnectionStatus\"8\n\x0f\x41\x63\x63ountStatuses\x12%\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x17.core.api.AccountStatus\"\x8c\x02\n\x11\x41\x63\x63ountConnection\x12\x36\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x11.core.api.AccountB\x12\xf2\xde\x1f\x0exorm:\"extends\"\x12?\n\tconn_addr\x18\x02 \x03(\x0b\x32\x1b.core.api.ConnectionAddressB\x0f\xf2\xde\x1f\x0bxorm:\"json\"\x12M\n\tconn_conf\x18\x03 \x03(\x0b\x32).core.api.AccountConnection.ConnConfEntryB\x0f\xf2\xde\x1f\x0bxorm:\"json\"\x1a/\n\rConnConfEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x12\x41\x63\x63ountConnections\x12)\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1b.core.api.AccountConnection\"\x85\x01\n\rExchangeRates\x12/\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32!.core.api.ExchangeRates.DataEntry\x1a\x43\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.core.api.ExchangeRate:\x02\x38\x01\"8\n\x10\x45xchangeRateList\x12$\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x16.core.api.ExchangeRate\"Y\n\x0c\x45xchangeRate\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\x12\x15\n\rfrom_currency\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\x01\x12\x11\n\trate_time\x18\x04 \x01(\t\"\"\n\x0e\x43ryptoCurrency\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\":\n\x10\x43ryptoCurrencies\x12&\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x18.core.api.CryptoCurrency\"_\n\x06Market\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x10\n\x08passflag\x18\x03 \x01(\x08\x12\'\n\x07subject\x18\x04 \x01(\x0e\x32\x16.core.api.SecurityType\")\n\x07Markets\x12\x1e\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x10.core.api.Market\"\x1a\n\nValidCoins\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"\xbe\x03\n\x0b\x42\x61\x63ktestReq\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x14\n\x0cinitial_cash\x18\x02 \x01(\x01\x12-\n\x11initial_positions\x18\n \x03(\x0b\x32\x12.core.api.Position\x12\x19\n\x11transaction_ratio\x18\x03 \x01(\x01\x12\x18\n\x10\x63ommission_ratio\x18\x04 \x01(\x01\x12\x16\n\x0eslippage_ratio\x18\x05 \x01(\x01\x12\x34\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x32\n\x08\x65nd_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x0c\n\x04mode\x18\x08 \x01(\x05\x12\x1f\n\x06orders\x18\t \x03(\x0b\x32\x0f.core.api.Order\x12\x17\n\x0fnot_save_result\x18\x0b \x01(\x08\x12-\n\x0f\x63omission_infos\x18\x0c \x03(\x0b\x32\x14.core.api.Commission\x12\'\n\x0einitial_assets\x18\r \x03(\x0b\x32\x0f.core.api.Asset\"R\n\x08Progress\x12\x10\n\x08progress\x18\x01 \x01(\x02\x12\x34\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"\xdb\x02\n\x0b\x42\x61\x63ktestRes\x12\x13\n\x0b\x62\x61\x63ktest_id\x18\x01 \x01(\t\x12&\n\x07request\x18\x02 \x01(\x0b\x32\x15.core.api.BacktestReq\x12$\n\x08position\x18\x03 \x03(\x0b\x32\x12.core.api.Position\x12&\n\tindicator\x18\x04 \x01(\x0b\x32\x13.core.api.Indicator\x12$\n\x08progress\x18\x05 \x01(\x0b\x32\x12.core.api.Progress\x12\x0f\n\x07\x63omment\x18\x06 \x01(\t\x12\x1e\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x0f.core.api.Error\x12\x34\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x34\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"\xb8\x04\n\tIndicator\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0b\n\x03pnl\x18\x10 \x01(\x01\x12\x11\n\tpnl_ratio\x18\x02 \x01(\x01\x12\x18\n\x10pnl_ratio_annual\x18\x03 \x01(\x01\x12\x12\n\ncommission\x18\x0f \x01(\x01\x12\x0c\n\x04\x63\x61sh\x18\x11 \x01(\x01\x12\x12\n\nbanch_mark\x18\x12 \x01(\x01\x12\x18\n\x10\x62\x61nch_mark_ratio\x18\x13 \x01(\x01\x12\x0c\n\x04\x62\x65ta\x18\x14 \x01(\x01\x12\r\n\x05\x61lpha\x18\x15 \x01(\x01\x12\x12\n\nvolatility\x18\x16 \x01(\x01\x12\x0c\n\x04up_p\x18\x17 \x01(\x01\x12\x13\n\x0bmax_up_days\x18\x18 \x01(\x05\x12\x15\n\rmax_down_days\x18\x19 \x01(\x05\x12\x13\n\x0bsharp_ratio\x18\x04 \x01(\x01\x12\x14\n\x0cmax_drawdown\x18\x05 \x01(\x01\x12\x12\n\nrisk_ratio\x18\x06 \x01(\x01\x12\x12\n\nopen_count\x18\x07 \x01(\x05\x12\x13\n\x0b\x63lose_count\x18\x08 \x01(\x05\x12\x11\n\twin_count\x18\t \x01(\x05\x12\x12\n\nlose_count\x18\n \x01(\x05\x12\x11\n\twin_ratio\x18\x0b \x01(\x01\x12\x14\n\x0c\x63\x61lmar_ratio\x18\x0c \x01(\x01\x12\x34\n\ncreated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x34\n\nupdated_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"/\n\nIndicators\x12!\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x13.core.api.Indicator\"\xaa\x05\n\x11IndicatorDuration\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x11\n\tpnl_ratio\x18\x02 \x01(\x01\x12\x0b\n\x03pnl\x18\x03 \x01(\x01\x12\x0c\n\x04\x66pnl\x18\x04 \x01(\x01\x12\x0e\n\x06\x66rozen\x18\x05 \x01(\x01\x12\x0c\n\x04\x63\x61sh\x18\x06 \x01(\x01\x12\x0b\n\x03nav\x18\x07 \x01(\x01\x12\x36\n\tpositions\x18\x08 \x03(\x0b\x32\x12.core.api.PositionB\x0f\xf2\xde\x1f\x0bxorm:\"json\"\x12\x12\n\nbanch_mark\x18\x14 \x01(\x01\x12\x11\n\twin_ratio\x18\x15 \x01(\x01\x12\x18\n\x10pnl_ratio_annual\x18\x16 \x01(\x01\x12\x18\n\x10\x62\x61nch_mark_ratio\x18\x17 \x01(\x01\x12\x13\n\x0bsharp_ratio\x18\x18 \x01(\x01\x12\x14\n\x0cmax_drawdown\x18\x19 \x01(\x01\x12\x14\n\x0c\x63\x61lmar_ratio\x18\x1a \x01(\x01\x12\x0c\n\x04\x62\x65ta\x18\x1b \x01(\x01\x12\r\n\x05\x61lpha\x18\x1c \x01(\x01\x12\x12\n\nvolatility\x18\x1d \x01(\x01\x12\x0c\n\x04up_p\x18\x1e \x01(\x01\x12\x13\n\x0bmax_up_days\x18\x1f \x01(\x05\x12\x15\n\rmax_down_days\x18  \x01(\x05\x12\x0f\n\x07\x63um_pnl\x18\t \x01(\x01\x12\x0f\n\x07\x63um_buy\x18\n \x01(\x01\x12\x10\n\x08\x63um_sell\x18\x0b \x01(\x01\x12\x16\n\x0e\x63um_commission\x18\x0c \x01(\x01\x12\x31\n\x08\x64uration\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01\x12\x34\n\ncreated_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x34\n\nupdated_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"?\n\x12IndicatorDurations\x12)\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1b.core.api.IndicatorDuration\":\n\x0cOrderSummary\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x16\n\x0eunfinish_count\x18\x02 \x01(\x05\"7\n\x0fOrderSummaryNum\x12$\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x16.core.api.OrderSummary\"<\n\x10TradeMessageList\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1a.core.api.TradeMessageData\"K\n\x10TradeMessageData\x12$\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x16.core.api.TradeMessage\x12\x11\n\tcount_num\x18\x02 \x01(\x05\"\xe2\x01\n\x0cTradeMessage\x12\x1d\n\x06msg_id\x18\x01 \x01(\tB\r\xf2\xde\x1f\txorm:\"pk\"\x12\x0f\n\x07user_id\x18\n \x01(\t\x12\x10\n\x08msg_text\x18\x02 \x01(\t\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x13\n\x0bstrategy_id\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\x05\x12\x0f\n\x07nf_flag\x18\x06 \x01(\t\x12\x14\n\x0cnft_order_id\x18\x07 \x01(\t\x12\x10\n\x08opt_info\x18\x08 \x01(\t\x12\"\n\x08msg_time\x18\t \x01(\x03\x42\x10\xf2\xde\x1f\x0cxorm:\"index\"\"@\n\x12\x45xecrptMessageList\x12*\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.core.api.ExecrptMessageData\"O\n\x12\x45xecrptMessageData\x12&\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x18.core.api.ExecrptMessage\x12\x11\n\tcount_num\x18\x02 \x01(\x05\"\xe4\x01\n\x0e\x45xecrptMessage\x12\x1d\n\x06msg_id\x18\x01 \x01(\tB\r\xf2\xde\x1f\txorm:\"pk\"\x12\x0f\n\x07user_id\x18\n \x01(\t\x12\x10\n\x08msg_text\x18\x02 \x01(\t\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x13\n\x0bstrategy_id\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\x05\x12\x0f\n\x07nf_flag\x18\x06 \x01(\t\x12\x14\n\x0cnft_order_id\x18\x07 \x01(\t\x12\x10\n\x08opt_info\x18\x08 \x01(\t\x12\"\n\x08msg_time\x18\t \x01(\x03\x42\x10\xf2\xde\x1f\x0cxorm:\"index\"\"8\n\x0eSysMessageList\x12&\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x18.core.api.SysMessageData\"G\n\x0eSysMessageData\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.core.api.SysMessage\x12\x11\n\tcount_num\x18\x02 \x01(\x05\"\xaf\x01\n\nSysMessage\x12\x1d\n\x06msg_id\x18\x01 \x01(\x03\x42\r\xf2\xde\x1f\txorm:\"pk\"\x12\x10\n\x08msg_text\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\x05\x12\r\n\x05level\x18\x06 \x01(\x05\x12\x10\n\x08opt_info\x18\x08 \x01(\t\x12\"\n\x08msg_time\x18\t \x01(\x03\x42\x10\xf2\xde\x1f\x0cxorm:\"index\"\x12\x0f\n\x07user_id\x18\n \x01(\t\x12\x0c\n\x04lang\x18\x0b \x01(\t\"\x81\x01\n\nDepthsight\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x01\x12\x0c\n\x04side\x18\x04 \x01(\x05\x12\x10\n\x08self_vol\x18\x05 \x01(\x01\x12\x11\n\tother_vol\x18\x06 \x01(\x01\x12\x11\n\tself_rate\x18\x07 \x01(\x01\"X\n\x0e\x44\x65pthsightList\x12\"\n\x04\x62ids\x18\x01 \x03(\x0b\x32\x14.core.api.Depthsight\x12\"\n\x04\x61sks\x18\x02 \x03(\x0b\x32\x14.core.api.Depthsight\";\n\x11\x44\x65pthsightListObj\x12&\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x18.core.api.DepthsightList*\x94\x02\n\x08\x45xecType\x12\x14\n\x10\x45xecType_Unknown\x10\x00\x12\x13\n\x0f\x45xecType_Failed\x10\x01\x12\x10\n\x0c\x45xecType_New\x10\x02\x12\x1c\n\x18\x45xecType_PartiallyFilled\x10\x03\x12\x1e\n\x1a\x45xecType_PartiallyCanceled\x10\x04\x12\x13\n\x0f\x45xecType_Filled\x10\x05\x12\x15\n\x11\x45xecType_Canceled\x10\x06\x12\x14\n\x10\x45xecType_Expired\x10\x07\x12\x15\n\x11\x45xecType_Rejected\x10\x08\x12\x17\n\x13\x45xecType_PendingNew\x10\n\x12\x1b\n\x17\x45xecType_CancelRejected\x10\x13*\x98\x02\n\x0bOrderStatus\x12\x17\n\x13OrderStatus_Unknown\x10\x00\x12\x16\n\x12OrderStatus_Failed\x10\x01\x12\x13\n\x0fOrderStatus_New\x10\x02\x12\x1f\n\x1bOrderStatus_PartiallyFilled\x10\x03\x12!\n\x1dOrderStatus_PartiallyCanceled\x10\x04\x12\x16\n\x12OrderStatus_Filled\x10\x05\x12\x18\n\x14OrderStatus_Canceled\x10\x06\x12\x17\n\x13OrderStatus_Expired\x10\x07\x12\x18\n\x14OrderStatus_Rejected\x10\x08\x12\x1a\n\x16OrderStatus_PendingNew\x10\n*\xcc\x07\n\x11OrderRejectReason\x12\x1d\n\x19OrderRejectReason_Unknown\x10\x00\x12)\n%OrderRejectReason_RiskRuleCheckFailed\x10\x01\x12\"\n\x1eOrderRejectReason_NoEnoughCash\x10\x02\x12&\n\"OrderRejectReason_NoEnoughPosition\x10\x03\x12&\n\"OrderRejectReason_IllegalAccountId\x10\x04\x12\'\n#OrderRejectReason_IllegalStrategyId\x10\x05\x12#\n\x1fOrderRejectReason_IllegalSymbol\x10\x06\x12#\n\x1fOrderRejectReason_IllegalVolume\x10\x07\x12\"\n\x1eOrderRejectReason_IllegalPrice\x10\x08\x12%\n!OrderRejectReason_AccountDisabled\x10\n\x12)\n%OrderRejectReason_AccountDisconnected\x10\x0b\x12&\n\"OrderRejectReason_AccountLoggedout\x10\x0c\x12)\n%OrderRejectReason_NotInTradingSession\x10\r\x12+\n\'OrderRejectReason_OrderTypeNotSupported\x10\x0e\x12\x1e\n\x1aOrderRejectReason_Throttle\x10\x0f\x12&\n\"OrderRejectReason_SymbolSusppended\x10\x10\x12!\n\x1dOrderRejectReason_IllegalSide\x10\x11\x12+\n\'OrderRejectReason_RrefuseLeverageChange\x10\x12\x12#\n\x1eOrderRejectReason_NetworkError\x10\xde\x07\x12\x1f\n\x1aOrderRejectReason_Internal\x10\xe7\x07\x12*\n&CancelOrderRejectReason_OrderFinalized\x10\x65\x12(\n$CancelOrderRejectReason_UnknownOrder\x10\x66\x12(\n$CancelOrderRejectReason_BrokerOption\x10g\x12\x32\n.CancelOrderRejectReason_AlreadyInPendingCancel\x10h*\xa1\x02\n\tOrderSide\x12\x15\n\x11OrderSide_Unknown\x10\x00\x12\x11\n\rOrderSide_Buy\x10\x01\x12\x12\n\x0eOrderSide_Sell\x10\x02\x12\x16\n\x12OrderSide_Buy_Open\x10\x03\x12\x17\n\x13OrderSide_Buy_Close\x10\x04\x12\x17\n\x13OrderSide_Sell_Open\x10\x05\x12\x18\n\x14OrderSide_Sell_Close\x10\x06\x12\x1e\n\x1aOrderSide_Sell_Liquidation\x10\x07\x12\x19\n\x15OrderSide_Sell_Reduce\x10\x08\x12\x1d\n\x19OrderSide_Buy_Liquidation\x10\t\x12\x18\n\x14OrderSide_Buy_Reduce\x10\n*\xbc\x01\n\x0cSecurityType\x12\x19\n\x15SecurityType_Physical\x10\x00\x12\x17\n\x13SecurityType_Future\x10\x01\x12\x18\n\x14SecurityType_Unknown\x10\x02\x12\x16\n\x12SecurityType_Stock\x10\x03\x12\x15\n\x11SecurityType_Fund\x10\x04\x12\x16\n\x12SecurityType_Index\x10\x05\x12\x17\n\x13SecurityType_Option\x10\x06*\xb7\x01\n\tOrderType\x12\x15\n\x11OrderType_Unknown\x10\x00\x12\x13\n\x0fOrderType_Limit\x10\x01\x12\x14\n\x10OrderType_Market\x10\x02\x12\x18\n\x14OrderType_StopMarket\x10\x03\x12\x17\n\x13OrderType_StopLimit\x10\x04\x12\x1a\n\x16OrderType_ProfitMarket\x10\x05\x12\x19\n\x15OrderType_ProfitLimit\x10\x06*\x97\x01\n\x08\x45xecInst\x12\x19\n\x15\x45xecInstType_PostOnly\x10\x00\x12\x1a\n\x16\x45xecInstType_MarkPrice\x10\x01\x12\x1b\n\x17\x45xecInstType_IndexPrice\x10\x02\x12\x1a\n\x16\x45xecInstType_LastPrice\x10\x03\x12\x1b\n\x17\x45xecInstType_ReduceOnly\x10\x04*W\n\x0cPositionSide\x12\x18\n\x14PositionSide_Unknown\x10\x00\x12\x15\n\x11PositionSide_Long\x10\x01\x12\x16\n\x12PositionSide_Short\x10\x02*\xa1\x01\n\x0ePositionEffect\x12\x1a\n\x16PositionEffect_Unknown\x10\x00\x12\x17\n\x13PositionEffect_Open\x10\x01\x12\x18\n\x14PositionEffect_Close\x10\x02\x12\x1d\n\x19PositionEffect_CloseToday\x10\x03\x12!\n\x1dPositionEffect_CloseYesterday\x10\x04*\x88\x01\n\x18\x43\x61shPositionChangeReason\x12$\n CashPositionChangeReason_Unknown\x10\x00\x12\"\n\x1e\x43\x61shPositionChangeReason_Trade\x10\x01\x12\"\n\x1e\x43\x61shPositionChangeReason_Inout\x10\x02*^\n\x08OrderSrc\x12\x13\n\x0fOrderSrc_Unknow\x10\x00\x12\x13\n\x0fOrderSrc_Manual\x10\x01\x12\x11\n\rOrderSrc_Auto\x10\x02\x12\x15\n\x11OrderSrc_Exchange\x10\x03*R\n\x0c\x45rrorCodeFun\x12\x14\n\x10\x45rrorCodeFun_one\x10\x00\x12\x14\n\x10\x45rrorCodeFun_two\x10\x01\x12\x16\n\x12\x45rrorCodeFun_three\x10\x02*l\n\x0b\x41\x63\x63ountType\x12\x17\n\x13\x41\x63\x63ountType_Unknown\x10\x00\x12\x14\n\x10\x41\x63\x63ountType_Spot\x10\x01\x12\x16\n\x12\x41\x63\x63ountType_Margin\x10\x02\x12\x16\n\x12\x41\x63\x63ountType_Future\x10\x03*<\n\x05Model\x12\x10\n\x0cModel_unknow\x10\x00\x12\x0e\n\nModel_Full\x10\x01\x12\x11\n\rModel_Isolate\x10\x02*Y\n\x0c\x42\x61\x63ktestMode\x12\x18\n\x14\x42\x61\x63ktestMode_Unknown\x10\x00\x12\x17\n\x13\x42\x61\x63ktestMode_Stream\x10\x01\x12\x16\n\x12\x42\x61\x63ktestMode_Batch\x10\x02*T\n\x0bSysMsgLevel\x12\x13\n\x0fSysMsgLevel_All\x10\x00\x12\x16\n\x12SysMsgLevel_Normal\x10\x01\x12\x18\n\x14SysMsgLevel_Critical\x10\x02*O\n\nSysMsgType\x12\x12\n\x0eSysMsgType_All\x10\x00\x12\x16\n\x12SysMsgType_Message\x10\x01\x12\x15\n\x11SysMsgType_Update\x10\x02\x42T\n&com.nextfintech.tradingcenter.rpc.dataP\x01Z(nextfin.com/nfplatform/core/api;core_apib\x06proto3')
  ,
  dependencies=[core_dot_api_dot_common__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])

_EXECTYPE = _descriptor.EnumDescriptor(
  name='ExecType',
  full_name='core.api.ExecType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ExecType_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_Failed', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_New', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_PartiallyFilled', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_PartiallyCanceled', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_Filled', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_Canceled', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_Expired', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_Rejected', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_PendingNew', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecType_CancelRejected', index=10, number=19,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=9323,
  serialized_end=9599,
)
_sym_db.RegisterEnumDescriptor(_EXECTYPE)

ExecType = enum_type_wrapper.EnumTypeWrapper(_EXECTYPE)
_ORDERSTATUS = _descriptor.EnumDescriptor(
  name='OrderStatus',
  full_name='core.api.OrderStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_Failed', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_New', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_PartiallyFilled', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_PartiallyCanceled', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_Filled', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_Canceled', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_Expired', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_Rejected', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderStatus_PendingNew', index=9, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=9602,
  serialized_end=9882,
)
_sym_db.RegisterEnumDescriptor(_ORDERSTATUS)

OrderStatus = enum_type_wrapper.EnumTypeWrapper(_ORDERSTATUS)
_ORDERREJECTREASON = _descriptor.EnumDescriptor(
  name='OrderRejectReason',
  full_name='core.api.OrderRejectReason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_RiskRuleCheckFailed', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_NoEnoughCash', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_NoEnoughPosition', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_IllegalAccountId', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_IllegalStrategyId', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_IllegalSymbol', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_IllegalVolume', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_IllegalPrice', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_AccountDisabled', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_AccountDisconnected', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_AccountLoggedout', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_NotInTradingSession', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_OrderTypeNotSupported', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_Throttle', index=14, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_SymbolSusppended', index=15, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_IllegalSide', index=16, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_RrefuseLeverageChange', index=17, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_NetworkError', index=18, number=990,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderRejectReason_Internal', index=19, number=999,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CancelOrderRejectReason_OrderFinalized', index=20, number=101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CancelOrderRejectReason_UnknownOrder', index=21, number=102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CancelOrderRejectReason_BrokerOption', index=22, number=103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CancelOrderRejectReason_AlreadyInPendingCancel', index=23, number=104,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=9885,
  serialized_end=10857,
)
_sym_db.RegisterEnumDescriptor(_ORDERREJECTREASON)

OrderRejectReason = enum_type_wrapper.EnumTypeWrapper(_ORDERREJECTREASON)
_ORDERSIDE = _descriptor.EnumDescriptor(
  name='OrderSide',
  full_name='core.api.OrderSide',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Buy', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Sell', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Buy_Open', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Buy_Close', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Sell_Open', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Sell_Close', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Sell_Liquidation', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Sell_Reduce', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Buy_Liquidation', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSide_Buy_Reduce', index=10, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10860,
  serialized_end=11149,
)
_sym_db.RegisterEnumDescriptor(_ORDERSIDE)

OrderSide = enum_type_wrapper.EnumTypeWrapper(_ORDERSIDE)
_SECURITYTYPE = _descriptor.EnumDescriptor(
  name='SecurityType',
  full_name='core.api.SecurityType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SecurityType_Physical', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SecurityType_Future', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SecurityType_Unknown', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SecurityType_Stock', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SecurityType_Fund', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SecurityType_Index', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SecurityType_Option', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11152,
  serialized_end=11340,
)
_sym_db.RegisterEnumDescriptor(_SECURITYTYPE)

SecurityType = enum_type_wrapper.EnumTypeWrapper(_SECURITYTYPE)
_ORDERTYPE = _descriptor.EnumDescriptor(
  name='OrderType',
  full_name='core.api.OrderType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OrderType_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderType_Limit', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderType_Market', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderType_StopMarket', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderType_StopLimit', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderType_ProfitMarket', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderType_ProfitLimit', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11343,
  serialized_end=11526,
)
_sym_db.RegisterEnumDescriptor(_ORDERTYPE)

OrderType = enum_type_wrapper.EnumTypeWrapper(_ORDERTYPE)
_EXECINST = _descriptor.EnumDescriptor(
  name='ExecInst',
  full_name='core.api.ExecInst',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ExecInstType_PostOnly', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecInstType_MarkPrice', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecInstType_IndexPrice', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecInstType_LastPrice', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecInstType_ReduceOnly', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11529,
  serialized_end=11680,
)
_sym_db.RegisterEnumDescriptor(_EXECINST)

ExecInst = enum_type_wrapper.EnumTypeWrapper(_EXECINST)
_POSITIONSIDE = _descriptor.EnumDescriptor(
  name='PositionSide',
  full_name='core.api.PositionSide',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PositionSide_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PositionSide_Long', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PositionSide_Short', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11682,
  serialized_end=11769,
)
_sym_db.RegisterEnumDescriptor(_POSITIONSIDE)

PositionSide = enum_type_wrapper.EnumTypeWrapper(_POSITIONSIDE)
_POSITIONEFFECT = _descriptor.EnumDescriptor(
  name='PositionEffect',
  full_name='core.api.PositionEffect',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PositionEffect_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PositionEffect_Open', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PositionEffect_Close', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PositionEffect_CloseToday', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PositionEffect_CloseYesterday', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11772,
  serialized_end=11933,
)
_sym_db.RegisterEnumDescriptor(_POSITIONEFFECT)

PositionEffect = enum_type_wrapper.EnumTypeWrapper(_POSITIONEFFECT)
_CASHPOSITIONCHANGEREASON = _descriptor.EnumDescriptor(
  name='CashPositionChangeReason',
  full_name='core.api.CashPositionChangeReason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CashPositionChangeReason_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CashPositionChangeReason_Trade', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CashPositionChangeReason_Inout', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11936,
  serialized_end=12072,
)
_sym_db.RegisterEnumDescriptor(_CASHPOSITIONCHANGEREASON)

CashPositionChangeReason = enum_type_wrapper.EnumTypeWrapper(_CASHPOSITIONCHANGEREASON)
_ORDERSRC = _descriptor.EnumDescriptor(
  name='OrderSrc',
  full_name='core.api.OrderSrc',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OrderSrc_Unknow', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSrc_Manual', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSrc_Auto', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OrderSrc_Exchange', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12074,
  serialized_end=12168,
)
_sym_db.RegisterEnumDescriptor(_ORDERSRC)

OrderSrc = enum_type_wrapper.EnumTypeWrapper(_ORDERSRC)
_ERRORCODEFUN = _descriptor.EnumDescriptor(
  name='ErrorCodeFun',
  full_name='core.api.ErrorCodeFun',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ErrorCodeFun_one', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ErrorCodeFun_two', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ErrorCodeFun_three', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12170,
  serialized_end=12252,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODEFUN)

ErrorCodeFun = enum_type_wrapper.EnumTypeWrapper(_ERRORCODEFUN)
_ACCOUNTTYPE = _descriptor.EnumDescriptor(
  name='AccountType',
  full_name='core.api.AccountType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AccountType_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AccountType_Spot', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AccountType_Margin', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AccountType_Future', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12254,
  serialized_end=12362,
)
_sym_db.RegisterEnumDescriptor(_ACCOUNTTYPE)

AccountType = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTTYPE)
_MODEL = _descriptor.EnumDescriptor(
  name='Model',
  full_name='core.api.Model',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Model_unknow', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Model_Full', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Model_Isolate', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12364,
  serialized_end=12424,
)
_sym_db.RegisterEnumDescriptor(_MODEL)

Model = enum_type_wrapper.EnumTypeWrapper(_MODEL)
_BACKTESTMODE = _descriptor.EnumDescriptor(
  name='BacktestMode',
  full_name='core.api.BacktestMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BacktestMode_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BacktestMode_Stream', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BacktestMode_Batch', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12426,
  serialized_end=12515,
)
_sym_db.RegisterEnumDescriptor(_BACKTESTMODE)

BacktestMode = enum_type_wrapper.EnumTypeWrapper(_BACKTESTMODE)
_SYSMSGLEVEL = _descriptor.EnumDescriptor(
  name='SysMsgLevel',
  full_name='core.api.SysMsgLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SysMsgLevel_All', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SysMsgLevel_Normal', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SysMsgLevel_Critical', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12517,
  serialized_end=12601,
)
_sym_db.RegisterEnumDescriptor(_SYSMSGLEVEL)

SysMsgLevel = enum_type_wrapper.EnumTypeWrapper(_SYSMSGLEVEL)
_SYSMSGTYPE = _descriptor.EnumDescriptor(
  name='SysMsgType',
  full_name='core.api.SysMsgType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SysMsgType_All', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SysMsgType_Message', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SysMsgType_Update', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12603,
  serialized_end=12682,
)
_sym_db.RegisterEnumDescriptor(_SYSMSGTYPE)

SysMsgType = enum_type_wrapper.EnumTypeWrapper(_SYSMSGTYPE)
ExecType_Unknown = 0
ExecType_Failed = 1
ExecType_New = 2
ExecType_PartiallyFilled = 3
ExecType_PartiallyCanceled = 4
ExecType_Filled = 5
ExecType_Canceled = 6
ExecType_Expired = 7
ExecType_Rejected = 8
ExecType_PendingNew = 10
ExecType_CancelRejected = 19
OrderStatus_Unknown = 0
OrderStatus_Failed = 1
OrderStatus_New = 2
OrderStatus_PartiallyFilled = 3
OrderStatus_PartiallyCanceled = 4
OrderStatus_Filled = 5
OrderStatus_Canceled = 6
OrderStatus_Expired = 7
OrderStatus_Rejected = 8
OrderStatus_PendingNew = 10
OrderRejectReason_Unknown = 0
OrderRejectReason_RiskRuleCheckFailed = 1
OrderRejectReason_NoEnoughCash = 2
OrderRejectReason_NoEnoughPosition = 3
OrderRejectReason_IllegalAccountId = 4
OrderRejectReason_IllegalStrategyId = 5
OrderRejectReason_IllegalSymbol = 6
OrderRejectReason_IllegalVolume = 7
OrderRejectReason_IllegalPrice = 8
OrderRejectReason_AccountDisabled = 10
OrderRejectReason_AccountDisconnected = 11
OrderRejectReason_AccountLoggedout = 12
OrderRejectReason_NotInTradingSession = 13
OrderRejectReason_OrderTypeNotSupported = 14
OrderRejectReason_Throttle = 15
OrderRejectReason_SymbolSusppended = 16
OrderRejectReason_IllegalSide = 17
OrderRejectReason_RrefuseLeverageChange = 18
OrderRejectReason_NetworkError = 990
OrderRejectReason_Internal = 999
CancelOrderRejectReason_OrderFinalized = 101
CancelOrderRejectReason_UnknownOrder = 102
CancelOrderRejectReason_BrokerOption = 103
CancelOrderRejectReason_AlreadyInPendingCancel = 104
OrderSide_Unknown = 0
OrderSide_Buy = 1
OrderSide_Sell = 2
OrderSide_Buy_Open = 3
OrderSide_Buy_Close = 4
OrderSide_Sell_Open = 5
OrderSide_Sell_Close = 6
OrderSide_Sell_Liquidation = 7
OrderSide_Sell_Reduce = 8
OrderSide_Buy_Liquidation = 9
OrderSide_Buy_Reduce = 10
SecurityType_Physical = 0
SecurityType_Future = 1
SecurityType_Unknown = 2
SecurityType_Stock = 3
SecurityType_Fund = 4
SecurityType_Index = 5
SecurityType_Option = 6
OrderType_Unknown = 0
OrderType_Limit = 1
OrderType_Market = 2
OrderType_StopMarket = 3
OrderType_StopLimit = 4
OrderType_ProfitMarket = 5
OrderType_ProfitLimit = 6
ExecInstType_PostOnly = 0
ExecInstType_MarkPrice = 1
ExecInstType_IndexPrice = 2
ExecInstType_LastPrice = 3
ExecInstType_ReduceOnly = 4
PositionSide_Unknown = 0
PositionSide_Long = 1
PositionSide_Short = 2
PositionEffect_Unknown = 0
PositionEffect_Open = 1
PositionEffect_Close = 2
PositionEffect_CloseToday = 3
PositionEffect_CloseYesterday = 4
CashPositionChangeReason_Unknown = 0
CashPositionChangeReason_Trade = 1
CashPositionChangeReason_Inout = 2
OrderSrc_Unknow = 0
OrderSrc_Manual = 1
OrderSrc_Auto = 2
OrderSrc_Exchange = 3
ErrorCodeFun_one = 0
ErrorCodeFun_two = 1
ErrorCodeFun_three = 2
AccountType_Unknown = 0
AccountType_Spot = 1
AccountType_Margin = 2
AccountType_Future = 3
Model_unknow = 0
Model_Full = 1
Model_Isolate = 2
BacktestMode_Unknown = 0
BacktestMode_Stream = 1
BacktestMode_Batch = 2
SysMsgLevel_All = 0
SysMsgLevel_Normal = 1
SysMsgLevel_Critical = 2
SysMsgType_All = 0
SysMsgType_Message = 1
SysMsgType_Update = 2



_REQUESTCOMMONPARAMS = _descriptor.Descriptor(
  name='RequestCommonParams',
  full_name='core.api.RequestCommonParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_token', full_name='core.api.RequestCommonParams.user_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mac', full_name='core.api.RequestCommonParams.mac', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='core.api.RequestCommonParams.ip', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='op_station', full_name='core.api.RequestCommonParams.op_station', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=232,
)


_ORDER = _descriptor.Descriptor(
  name='Order',
  full_name='core.api.Order',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key', full_name='core.api.Order.api_key', index=0,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='core.api.Order.api_secret', index=1,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='core.api.Order.strategy_id', index=2,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.Order.account_id', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='core.api.Order.account_name', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cl_ord_id', full_name='core.api.Order.cl_ord_id', index=5,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='core.api.Order.order_id', index=6,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ex_ord_id', full_name='core.api.Order.ex_ord_id', index=7,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='core.api.Order.symbol', index=8,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='side', full_name='core.api.Order.side', index=9,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='core.api.Order.subject', index=10,
      number=37, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='core.api.Order.password', index=11,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='core.api.Order.order_type', index=12,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='order_src', full_name='core.api.Order.order_src', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='core.api.Order.status', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ord_rej_reason_detail', full_name='core.api.Order.ord_rej_reason_detail', index=15,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price', full_name='core.api.Order.price', index=16,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stop_price', full_name='core.api.Order.stop_price', index=17,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exec_inst', full_name='core.api.Order.exec_inst', index=18,
      number=39, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volume', full_name='core.api.Order.volume', index=19,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='core.api.Order.value', index=20,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filled_volume', full_name='core.api.Order.filled_volume', index=21,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filled_vwap', full_name='core.api.Order.filled_vwap', index=22,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filled_amount', full_name='core.api.Order.filled_amount', index=23,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filled_commission', full_name='core.api.Order.filled_commission', index=24,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filled_commi_coin', full_name='core.api.Order.filled_commi_coin', index=25,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filled_commi_volume', full_name='core.api.Order.filled_commi_volume', index=26,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model_type', full_name='core.api.Order.model_type', index=27,
      number=40, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leverage', full_name='core.api.Order.leverage', index=28,
      number=41, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='displayQty', full_name='core.api.Order.displayQty', index=29,
      number=43, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_in_force', full_name='core.api.Order.time_in_force', index=30,
      number=44, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.Order.created_at', index=31,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='core.api.Order.updated_at', index=32,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='symbol_old', full_name='core.api.Order.symbol_old', index=33,
      number=45, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='settle_time', full_name='core.api.Order.settle_time', index=34,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=1174,
)


_ORDERS_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='core.api.Orders.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='core.api.Orders.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='core.api.Orders.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1272,
  serialized_end=1321,
)

_ORDERS = _descriptor.Descriptor(
  name='Orders',
  full_name='core.api.Orders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.Orders.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='core.api.Orders.properties', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_ORDERS_PROPERTIESENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1177,
  serialized_end=1321,
)


_ORDERSPAGED = _descriptor.Descriptor(
  name='OrdersPaged',
  full_name='core.api.OrdersPaged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.OrdersPaged.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1368,
)


_EXECRPT = _descriptor.Descriptor(
  name='ExecRpt',
  full_name='core.api.ExecRpt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='core.api.ExecRpt.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.ExecRpt.account_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='core.api.ExecRpt.account_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cl_ord_id', full_name='core.api.ExecRpt.cl_ord_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='core.api.ExecRpt.order_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ex_ord_id', full_name='core.api.ExecRpt.ex_ord_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exec_id', full_name='core.api.ExecRpt.exec_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='core.api.ExecRpt.symbol', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='side', full_name='core.api.ExecRpt.side', index=8,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ord_rej_reason_detail', full_name='core.api.ExecRpt.ord_rej_reason_detail', index=9,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exec_type', full_name='core.api.ExecRpt.exec_type', index=10,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price', full_name='core.api.ExecRpt.price', index=11,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volume', full_name='core.api.ExecRpt.volume', index=12,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='core.api.ExecRpt.amount', index=13,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='order_src', full_name='core.api.ExecRpt.order_src', index=14,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.ExecRpt.created_at', index=15,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='original_price', full_name='core.api.ExecRpt.original_price', index=16,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_volume', full_name='core.api.ExecRpt.original_volume', index=17,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='execinst', full_name='core.api.ExecRpt.execinst', index=18,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='core.api.ExecRpt.currency', index=19,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='liquidation', full_name='core.api.ExecRpt.liquidation', index=20,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='core.api.ExecRpt.text', index=21,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='core.api.ExecRpt.subject', index=22,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ordType', full_name='core.api.ExecRpt.ordType', index=23,
      number=29, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base', full_name='core.api.ExecRpt.base', index=24,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quote', full_name='core.api.ExecRpt.quote', index=25,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stop_price', full_name='core.api.ExecRpt.stop_price', index=26,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1371,
  serialized_end=2025,
)


_EXECRPTS = _descriptor.Descriptor(
  name='ExecRpts',
  full_name='core.api.ExecRpts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.ExecRpts.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2027,
  serialized_end=2070,
)


_CASH = _descriptor.Descriptor(
  name='Cash',
  full_name='core.api.Cash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.Cash.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='core.api.Cash.account_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='core.api.Cash.currency', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frozen', full_name='core.api.Cash.frozen', index=3,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='available', full_name='core.api.Cash.available', index=4,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.Cash.created_at', index=5,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='core.api.Cash.updated_at', index=6,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2282,
)


_CASHES = _descriptor.Descriptor(
  name='Cashes',
  full_name='core.api.Cashes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.Cashes.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2322,
)


_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='core.api.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.Position.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='core.api.Position.account_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='core.api.Position.currency', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='side', full_name='core.api.Position.side', index=3,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frozen', full_name='core.api.Position.frozen', index=4,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='available', full_name='core.api.Position.available', index=5,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cash', full_name='core.api.Position.cash', index=6,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pop_rate', full_name='core.api.Position.pop_rate', index=7,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='core.api.Position.symbol', index=8,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base', full_name='core.api.Position.base', index=9,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quote', full_name='core.api.Position.quote', index=10,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='core.api.Position.subject', index=11,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='core.api.Position.amount', index=12,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='core.api.Position.value', index=13,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price', full_name='core.api.Position.price', index=14,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mark_price', full_name='core.api.Position.mark_price', index=15,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.Position.created_at', index=16,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='core.api.Position.updated_at', index=17,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='settle_at', full_name='core.api.Position.settle_at', index=18,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='maintain_margin', full_name='core.api.Position.maintain_margin', index=19,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='margin_rate', full_name='core.api.Position.margin_rate', index=20,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model_type', full_name='core.api.Position.model_type', index=21,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_commission', full_name='core.api.Position.current_commission', index=22,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='margin_currency', full_name='core.api.Position.margin_currency', index=23,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alert_rate', full_name='core.api.Position.alert_rate', index=24,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confirmed_profit', full_name='core.api.Position.confirmed_profit', index=25,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unconfirmed_profit_markprice', full_name='core.api.Position.unconfirmed_profit_markprice', index=26,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unconfirmed_profit', full_name='core.api.Position.unconfirmed_profit', index=27,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leverage', full_name='core.api.Position.leverage', index=28,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='settle_time', full_name='core.api.Position.settle_time', index=29,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='liquidation_price', full_name='core.api.Position.liquidation_price', index=30,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bankrupt_price', full_name='core.api.Position.bankrupt_price', index=31,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='init_margin_rate', full_name='core.api.Position.init_margin_rate', index=32,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avgEntryPrice', full_name='core.api.Position.avgEntryPrice', index=33,
      number=37, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='margin', full_name='core.api.Position.margin', index=34,
      number=38, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pos_state', full_name='core.api.Position.pos_state', index=35,
      number=39, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol_old', full_name='core.api.Position.symbol_old', index=36,
      number=40, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='can_reduce', full_name='core.api.Position.can_reduce', index=37,
      number=41, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='close_tfv', full_name='core.api.Position.close_tfv', index=38,
      number=42, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filled_balance', full_name='core.api.Position.filled_balance', index=39,
      number=43, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='profit', full_name='core.api.Position.profit', index=40,
      number=44, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pft_close_tfv', full_name='core.api.Position.pft_close_tfv', index=41,
      number=45, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='real_leverage', full_name='core.api.Position.real_leverage', index=42,
      number=46, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='liquidation_price_rl', full_name='core.api.Position.liquidation_price_rl', index=43,
      number=47, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2325,
  serialized_end=3420,
)


_SETTLEMENT = _descriptor.Descriptor(
  name='Settlement',
  full_name='core.api.Settlement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='core.api.Settlement.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='settled_price', full_name='core.api.Settlement.settled_price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='settled_time', full_name='core.api.Settlement.settled_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3422,
  serialized_end=3529,
)


_SETTLEMENTITEMS = _descriptor.Descriptor(
  name='SettlementItems',
  full_name='core.api.SettlementItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.SettlementItems.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3531,
  serialized_end=3584,
)


_STAT = _descriptor.Descriptor(
  name='Stat',
  full_name='core.api.Stat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='underlying_base', full_name='core.api.Stat.underlying_base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='core.api.Stat.currency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='turnover_24h', full_name='core.api.Stat.turnover_24h', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volume_24h', full_name='core.api.Stat.volume_24h', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_interest', full_name='core.api.Stat.open_interest', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_value', full_name='core.api.Stat.open_value', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3587,
  serialized_end=3721,
)


_STATITEMS = _descriptor.Descriptor(
  name='StatItems',
  full_name='core.api.StatItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.StatItems.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3723,
  serialized_end=3764,
)


_ASSET = _descriptor.Descriptor(
  name='Asset',
  full_name='core.api.Asset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='core.api.Asset.currency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='margin_balance', full_name='core.api.Asset.margin_balance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='available_balance', full_name='core.api.Asset.available_balance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='core.api.Asset.value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='realised_pnl', full_name='core.api.Asset.realised_pnl', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unrealised_pnl', full_name='core.api.Asset.unrealised_pnl', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='margin', full_name='core.api.Asset.margin', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='order_margin', full_name='core.api.Asset.order_margin', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='core.api.Asset.exchange', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3767,
  serialized_end=3960,
)


_MARGINASSETS = _descriptor.Descriptor(
  name='MarginAssets',
  full_name='core.api.MarginAssets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.MarginAssets.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3962,
  serialized_end=4007,
)


_GETMARGINASSETSRESP = _descriptor.Descriptor(
  name='GetMarginAssetsResp',
  full_name='core.api.GetMarginAssetsResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.GetMarginAssetsResp.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4009,
  serialized_end=4068,
)


_COMMISSION = _descriptor.Descriptor(
  name='Commission',
  full_name='core.api.Commission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange', full_name='core.api.Commission.exchange', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quote', full_name='core.api.Commission.quote', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commission_ratio', full_name='core.api.Commission.commission_ratio', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4070,
  serialized_end=4141,
)


_POSITIONS = _descriptor.Descriptor(
  name='Positions',
  full_name='core.api.Positions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.Positions.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4143,
  serialized_end=4188,
)


_ACCOUNT = _descriptor.Descriptor(
  name='Account',
  full_name='core.api.Account',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.Account.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\txorm:\"pk\"'))),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='core.api.Account.exchange', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='core.api.Account.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='core.api.Account.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='core.api.Account.api_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='secret_key', full_name='core.api.Account.secret_key', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='core.api.Account.password', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.Account.created_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='core.api.Account.updated_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"updated\"'))),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='core.api.Account.user_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_type', full_name='core.api.Account.account_type', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4191,
  serialized_end=4543,
)


_ACCOUNTS = _descriptor.Descriptor(
  name='Accounts',
  full_name='core.api.Accounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.Accounts.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4545,
  serialized_end=4588,
)


_ACCOUNTSTATUS = _descriptor.Descriptor(
  name='AccountStatus',
  full_name='core.api.AccountStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.AccountStatus.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='core.api.AccountStatus.status', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4590,
  serialized_end=4669,
)


_ACCOUNTSTATUSES = _descriptor.Descriptor(
  name='AccountStatuses',
  full_name='core.api.AccountStatuses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.AccountStatuses.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4671,
  serialized_end=4727,
)


_ACCOUNTCONNECTION_CONNCONFENTRY = _descriptor.Descriptor(
  name='ConnConfEntry',
  full_name='core.api.AccountConnection.ConnConfEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='core.api.AccountConnection.ConnConfEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='core.api.AccountConnection.ConnConfEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4951,
  serialized_end=4998,
)

_ACCOUNTCONNECTION = _descriptor.Descriptor(
  name='AccountConnection',
  full_name='core.api.AccountConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='core.api.AccountConnection.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\016xorm:\"extends\"'))),
    _descriptor.FieldDescriptor(
      name='conn_addr', full_name='core.api.AccountConnection.conn_addr', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\013xorm:\"json\"'))),
    _descriptor.FieldDescriptor(
      name='conn_conf', full_name='core.api.AccountConnection.conn_conf', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\013xorm:\"json\"'))),
  ],
  extensions=[
  ],
  nested_types=[_ACCOUNTCONNECTION_CONNCONFENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4730,
  serialized_end=4998,
)


_ACCOUNTCONNECTIONS = _descriptor.Descriptor(
  name='AccountConnections',
  full_name='core.api.AccountConnections',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.AccountConnections.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5000,
  serialized_end=5063,
)


_EXCHANGERATES_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='core.api.ExchangeRates.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='core.api.ExchangeRates.DataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='core.api.ExchangeRates.DataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5132,
  serialized_end=5199,
)

_EXCHANGERATES = _descriptor.Descriptor(
  name='ExchangeRates',
  full_name='core.api.ExchangeRates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.ExchangeRates.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_EXCHANGERATES_DATAENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5066,
  serialized_end=5199,
)


_EXCHANGERATELIST = _descriptor.Descriptor(
  name='ExchangeRateList',
  full_name='core.api.ExchangeRateList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.ExchangeRateList.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5201,
  serialized_end=5257,
)


_EXCHANGERATE = _descriptor.Descriptor(
  name='ExchangeRate',
  full_name='core.api.ExchangeRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='core.api.ExchangeRate.currency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_currency', full_name='core.api.ExchangeRate.from_currency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price', full_name='core.api.ExchangeRate.price', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate_time', full_name='core.api.ExchangeRate.rate_time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5259,
  serialized_end=5348,
)


_CRYPTOCURRENCY = _descriptor.Descriptor(
  name='CryptoCurrency',
  full_name='core.api.CryptoCurrency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='core.api.CryptoCurrency.currency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5350,
  serialized_end=5384,
)


_CRYPTOCURRENCIES = _descriptor.Descriptor(
  name='CryptoCurrencies',
  full_name='core.api.CryptoCurrencies',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.CryptoCurrencies.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5386,
  serialized_end=5444,
)


_MARKET = _descriptor.Descriptor(
  name='Market',
  full_name='core.api.Market',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='core.api.Market.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='core.api.Market.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passflag', full_name='core.api.Market.passflag', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='core.api.Market.subject', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5446,
  serialized_end=5541,
)


_MARKETS = _descriptor.Descriptor(
  name='Markets',
  full_name='core.api.Markets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.Markets.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5543,
  serialized_end=5584,
)


_VALIDCOINS = _descriptor.Descriptor(
  name='ValidCoins',
  full_name='core.api.ValidCoins',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.ValidCoins.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5586,
  serialized_end=5612,
)


_BACKTESTREQ = _descriptor.Descriptor(
  name='BacktestReq',
  full_name='core.api.BacktestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='core.api.BacktestReq.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initial_cash', full_name='core.api.BacktestReq.initial_cash', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initial_positions', full_name='core.api.BacktestReq.initial_positions', index=2,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transaction_ratio', full_name='core.api.BacktestReq.transaction_ratio', index=3,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commission_ratio', full_name='core.api.BacktestReq.commission_ratio', index=4,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slippage_ratio', full_name='core.api.BacktestReq.slippage_ratio', index=5,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='core.api.BacktestReq.start_time', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='core.api.BacktestReq.end_time', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='mode', full_name='core.api.BacktestReq.mode', index=8,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orders', full_name='core.api.BacktestReq.orders', index=9,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='not_save_result', full_name='core.api.BacktestReq.not_save_result', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comission_infos', full_name='core.api.BacktestReq.comission_infos', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initial_assets', full_name='core.api.BacktestReq.initial_assets', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5615,
  serialized_end=6061,
)


_PROGRESS = _descriptor.Descriptor(
  name='Progress',
  full_name='core.api.Progress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress', full_name='core.api.Progress.progress', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='core.api.Progress.updated_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6063,
  serialized_end=6145,
)


_BACKTESTRES = _descriptor.Descriptor(
  name='BacktestRes',
  full_name='core.api.BacktestRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='backtest_id', full_name='core.api.BacktestRes.backtest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request', full_name='core.api.BacktestRes.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='core.api.BacktestRes.position', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='indicator', full_name='core.api.BacktestRes.indicator', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='progress', full_name='core.api.BacktestRes.progress', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comment', full_name='core.api.BacktestRes.comment', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='core.api.BacktestRes.error', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.BacktestRes.created_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='core.api.BacktestRes.updated_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6148,
  serialized_end=6495,
)


_INDICATOR = _descriptor.Descriptor(
  name='Indicator',
  full_name='core.api.Indicator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.Indicator.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pnl', full_name='core.api.Indicator.pnl', index=1,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pnl_ratio', full_name='core.api.Indicator.pnl_ratio', index=2,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pnl_ratio_annual', full_name='core.api.Indicator.pnl_ratio_annual', index=3,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commission', full_name='core.api.Indicator.commission', index=4,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cash', full_name='core.api.Indicator.cash', index=5,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banch_mark', full_name='core.api.Indicator.banch_mark', index=6,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banch_mark_ratio', full_name='core.api.Indicator.banch_mark_ratio', index=7,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='beta', full_name='core.api.Indicator.beta', index=8,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alpha', full_name='core.api.Indicator.alpha', index=9,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volatility', full_name='core.api.Indicator.volatility', index=10,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='up_p', full_name='core.api.Indicator.up_p', index=11,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_up_days', full_name='core.api.Indicator.max_up_days', index=12,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_down_days', full_name='core.api.Indicator.max_down_days', index=13,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sharp_ratio', full_name='core.api.Indicator.sharp_ratio', index=14,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_drawdown', full_name='core.api.Indicator.max_drawdown', index=15,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='risk_ratio', full_name='core.api.Indicator.risk_ratio', index=16,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_count', full_name='core.api.Indicator.open_count', index=17,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='close_count', full_name='core.api.Indicator.close_count', index=18,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='win_count', full_name='core.api.Indicator.win_count', index=19,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lose_count', full_name='core.api.Indicator.lose_count', index=20,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='win_ratio', full_name='core.api.Indicator.win_ratio', index=21,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calmar_ratio', full_name='core.api.Indicator.calmar_ratio', index=22,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.Indicator.created_at', index=23,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='core.api.Indicator.updated_at', index=24,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6498,
  serialized_end=7066,
)


_INDICATORS = _descriptor.Descriptor(
  name='Indicators',
  full_name='core.api.Indicators',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.Indicators.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7068,
  serialized_end=7115,
)


_INDICATORDURATION = _descriptor.Descriptor(
  name='IndicatorDuration',
  full_name='core.api.IndicatorDuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.IndicatorDuration.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pnl_ratio', full_name='core.api.IndicatorDuration.pnl_ratio', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pnl', full_name='core.api.IndicatorDuration.pnl', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fpnl', full_name='core.api.IndicatorDuration.fpnl', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frozen', full_name='core.api.IndicatorDuration.frozen', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cash', full_name='core.api.IndicatorDuration.cash', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nav', full_name='core.api.IndicatorDuration.nav', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positions', full_name='core.api.IndicatorDuration.positions', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\013xorm:\"json\"'))),
    _descriptor.FieldDescriptor(
      name='banch_mark', full_name='core.api.IndicatorDuration.banch_mark', index=8,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='win_ratio', full_name='core.api.IndicatorDuration.win_ratio', index=9,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pnl_ratio_annual', full_name='core.api.IndicatorDuration.pnl_ratio_annual', index=10,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banch_mark_ratio', full_name='core.api.IndicatorDuration.banch_mark_ratio', index=11,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sharp_ratio', full_name='core.api.IndicatorDuration.sharp_ratio', index=12,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_drawdown', full_name='core.api.IndicatorDuration.max_drawdown', index=13,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calmar_ratio', full_name='core.api.IndicatorDuration.calmar_ratio', index=14,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='beta', full_name='core.api.IndicatorDuration.beta', index=15,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alpha', full_name='core.api.IndicatorDuration.alpha', index=16,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volatility', full_name='core.api.IndicatorDuration.volatility', index=17,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='up_p', full_name='core.api.IndicatorDuration.up_p', index=18,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_up_days', full_name='core.api.IndicatorDuration.max_up_days', index=19,
      number=31, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_down_days', full_name='core.api.IndicatorDuration.max_down_days', index=20,
      number=32, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cum_pnl', full_name='core.api.IndicatorDuration.cum_pnl', index=21,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cum_buy', full_name='core.api.IndicatorDuration.cum_buy', index=22,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cum_sell', full_name='core.api.IndicatorDuration.cum_sell', index=23,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cum_commission', full_name='core.api.IndicatorDuration.cum_commission', index=24,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='core.api.IndicatorDuration.duration', index=25,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\230\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.IndicatorDuration.created_at', index=26,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='core.api.IndicatorDuration.updated_at', index=27,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7118,
  serialized_end=7800,
)


_INDICATORDURATIONS = _descriptor.Descriptor(
  name='IndicatorDurations',
  full_name='core.api.IndicatorDurations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.IndicatorDurations.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7802,
  serialized_end=7865,
)


_ORDERSUMMARY = _descriptor.Descriptor(
  name='OrderSummary',
  full_name='core.api.OrderSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.OrderSummary.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unfinish_count', full_name='core.api.OrderSummary.unfinish_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7867,
  serialized_end=7925,
)


_ORDERSUMMARYNUM = _descriptor.Descriptor(
  name='OrderSummaryNum',
  full_name='core.api.OrderSummaryNum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.OrderSummaryNum.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7927,
  serialized_end=7982,
)


_TRADEMESSAGELIST = _descriptor.Descriptor(
  name='TradeMessageList',
  full_name='core.api.TradeMessageList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.TradeMessageList.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7984,
  serialized_end=8044,
)


_TRADEMESSAGEDATA = _descriptor.Descriptor(
  name='TradeMessageData',
  full_name='core.api.TradeMessageData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.TradeMessageData.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count_num', full_name='core.api.TradeMessageData.count_num', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8046,
  serialized_end=8121,
)


_TRADEMESSAGE = _descriptor.Descriptor(
  name='TradeMessage',
  full_name='core.api.TradeMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='core.api.TradeMessage.msg_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\txorm:\"pk\"'))),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='core.api.TradeMessage.user_id', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg_text', full_name='core.api.TradeMessage.msg_text', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='core.api.TradeMessage.exchange', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='core.api.TradeMessage.strategy_id', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='core.api.TradeMessage.type', index=5,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nf_flag', full_name='core.api.TradeMessage.nf_flag', index=6,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nft_order_id', full_name='core.api.TradeMessage.nft_order_id', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='opt_info', full_name='core.api.TradeMessage.opt_info', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg_time', full_name='core.api.TradeMessage.msg_time', index=9,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\014xorm:\"index\"'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8124,
  serialized_end=8350,
)


_EXECRPTMESSAGELIST = _descriptor.Descriptor(
  name='ExecrptMessageList',
  full_name='core.api.ExecrptMessageList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.ExecrptMessageList.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8352,
  serialized_end=8416,
)


_EXECRPTMESSAGEDATA = _descriptor.Descriptor(
  name='ExecrptMessageData',
  full_name='core.api.ExecrptMessageData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.ExecrptMessageData.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count_num', full_name='core.api.ExecrptMessageData.count_num', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8418,
  serialized_end=8497,
)


_EXECRPTMESSAGE = _descriptor.Descriptor(
  name='ExecrptMessage',
  full_name='core.api.ExecrptMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='core.api.ExecrptMessage.msg_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\txorm:\"pk\"'))),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='core.api.ExecrptMessage.user_id', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg_text', full_name='core.api.ExecrptMessage.msg_text', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='core.api.ExecrptMessage.exchange', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='core.api.ExecrptMessage.strategy_id', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='core.api.ExecrptMessage.type', index=5,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nf_flag', full_name='core.api.ExecrptMessage.nf_flag', index=6,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nft_order_id', full_name='core.api.ExecrptMessage.nft_order_id', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='opt_info', full_name='core.api.ExecrptMessage.opt_info', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg_time', full_name='core.api.ExecrptMessage.msg_time', index=9,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\014xorm:\"index\"'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8500,
  serialized_end=8728,
)


_SYSMESSAGELIST = _descriptor.Descriptor(
  name='SysMessageList',
  full_name='core.api.SysMessageList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.SysMessageList.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8730,
  serialized_end=8786,
)


_SYSMESSAGEDATA = _descriptor.Descriptor(
  name='SysMessageData',
  full_name='core.api.SysMessageData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.SysMessageData.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count_num', full_name='core.api.SysMessageData.count_num', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8788,
  serialized_end=8859,
)


_SYSMESSAGE = _descriptor.Descriptor(
  name='SysMessage',
  full_name='core.api.SysMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='core.api.SysMessage.msg_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\txorm:\"pk\"'))),
    _descriptor.FieldDescriptor(
      name='msg_text', full_name='core.api.SysMessage.msg_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='core.api.SysMessage.type', index=2,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='core.api.SysMessage.level', index=3,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='opt_info', full_name='core.api.SysMessage.opt_info', index=4,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg_time', full_name='core.api.SysMessage.msg_time', index=5,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\014xorm:\"index\"'))),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='core.api.SysMessage.user_id', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lang', full_name='core.api.SysMessage.lang', index=7,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8862,
  serialized_end=9037,
)


_DEPTHSIGHT = _descriptor.Descriptor(
  name='Depthsight',
  full_name='core.api.Depthsight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='core.api.Depthsight.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price', full_name='core.api.Depthsight.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volume', full_name='core.api.Depthsight.volume', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='side', full_name='core.api.Depthsight.side', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='self_vol', full_name='core.api.Depthsight.self_vol', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='other_vol', full_name='core.api.Depthsight.other_vol', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='self_rate', full_name='core.api.Depthsight.self_rate', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9040,
  serialized_end=9169,
)


_DEPTHSIGHTLIST = _descriptor.Descriptor(
  name='DepthsightList',
  full_name='core.api.DepthsightList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bids', full_name='core.api.DepthsightList.bids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asks', full_name='core.api.DepthsightList.asks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9171,
  serialized_end=9259,
)


_DEPTHSIGHTLISTOBJ = _descriptor.Descriptor(
  name='DepthsightListObj',
  full_name='core.api.DepthsightListObj',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.DepthsightListObj.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9261,
  serialized_end=9320,
)

_ORDER.fields_by_name['side'].enum_type = _ORDERSIDE
_ORDER.fields_by_name['subject'].enum_type = _SECURITYTYPE
_ORDER.fields_by_name['order_type'].enum_type = _ORDERTYPE
_ORDER.fields_by_name['order_src'].enum_type = _ORDERSRC
_ORDER.fields_by_name['status'].enum_type = _ORDERSTATUS
_ORDER.fields_by_name['model_type'].enum_type = _MODEL
_ORDER.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORDER.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORDER.fields_by_name['settle_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORDERS_PROPERTIESENTRY.containing_type = _ORDERS
_ORDERS.fields_by_name['data'].message_type = _ORDER
_ORDERS.fields_by_name['properties'].message_type = _ORDERS_PROPERTIESENTRY
_ORDERSPAGED.fields_by_name['data'].message_type = _ORDERS
_EXECRPT.fields_by_name['side'].enum_type = _ORDERSIDE
_EXECRPT.fields_by_name['exec_type'].enum_type = _EXECTYPE
_EXECRPT.fields_by_name['order_src'].enum_type = _ORDERSRC
_EXECRPT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXECRPT.fields_by_name['subject'].enum_type = _SECURITYTYPE
_EXECRPT.fields_by_name['ordType'].enum_type = _ORDERTYPE
_EXECRPTS.fields_by_name['data'].message_type = _EXECRPT
_CASH.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CASH.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CASHES.fields_by_name['data'].message_type = _CASH
_POSITION.fields_by_name['subject'].enum_type = _SECURITYTYPE
_POSITION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_POSITION.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_POSITION.fields_by_name['settle_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_POSITION.fields_by_name['model_type'].enum_type = _MODEL
_POSITION.fields_by_name['settle_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SETTLEMENT.fields_by_name['settled_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SETTLEMENTITEMS.fields_by_name['data'].message_type = _SETTLEMENT
_STATITEMS.fields_by_name['data'].message_type = _STAT
_MARGINASSETS.fields_by_name['data'].message_type = _ASSET
_GETMARGINASSETSRESP.fields_by_name['data'].message_type = _MARGINASSETS
_POSITIONS.fields_by_name['data'].message_type = _POSITION
_ACCOUNT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACCOUNT.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACCOUNT.fields_by_name['account_type'].enum_type = _ACCOUNTTYPE
_ACCOUNTS.fields_by_name['data'].message_type = _ACCOUNT
_ACCOUNTSTATUS.fields_by_name['status'].message_type = core_dot_api_dot_common__pb2._CONNECTIONSTATUS
_ACCOUNTSTATUSES.fields_by_name['data'].message_type = _ACCOUNTSTATUS
_ACCOUNTCONNECTION_CONNCONFENTRY.containing_type = _ACCOUNTCONNECTION
_ACCOUNTCONNECTION.fields_by_name['account'].message_type = _ACCOUNT
_ACCOUNTCONNECTION.fields_by_name['conn_addr'].message_type = core_dot_api_dot_common__pb2._CONNECTIONADDRESS
_ACCOUNTCONNECTION.fields_by_name['conn_conf'].message_type = _ACCOUNTCONNECTION_CONNCONFENTRY
_ACCOUNTCONNECTIONS.fields_by_name['data'].message_type = _ACCOUNTCONNECTION
_EXCHANGERATES_DATAENTRY.fields_by_name['value'].message_type = _EXCHANGERATE
_EXCHANGERATES_DATAENTRY.containing_type = _EXCHANGERATES
_EXCHANGERATES.fields_by_name['data'].message_type = _EXCHANGERATES_DATAENTRY
_EXCHANGERATELIST.fields_by_name['data'].message_type = _EXCHANGERATE
_CRYPTOCURRENCIES.fields_by_name['data'].message_type = _CRYPTOCURRENCY
_MARKET.fields_by_name['subject'].enum_type = _SECURITYTYPE
_MARKETS.fields_by_name['data'].message_type = _MARKET
_BACKTESTREQ.fields_by_name['initial_positions'].message_type = _POSITION
_BACKTESTREQ.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BACKTESTREQ.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BACKTESTREQ.fields_by_name['orders'].message_type = _ORDER
_BACKTESTREQ.fields_by_name['comission_infos'].message_type = _COMMISSION
_BACKTESTREQ.fields_by_name['initial_assets'].message_type = _ASSET
_PROGRESS.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BACKTESTRES.fields_by_name['request'].message_type = _BACKTESTREQ
_BACKTESTRES.fields_by_name['position'].message_type = _POSITION
_BACKTESTRES.fields_by_name['indicator'].message_type = _INDICATOR
_BACKTESTRES.fields_by_name['progress'].message_type = _PROGRESS
_BACKTESTRES.fields_by_name['error'].message_type = core_dot_api_dot_common__pb2._ERROR
_BACKTESTRES.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BACKTESTRES.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INDICATOR.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INDICATOR.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INDICATORS.fields_by_name['data'].message_type = _INDICATOR
_INDICATORDURATION.fields_by_name['positions'].message_type = _POSITION
_INDICATORDURATION.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_INDICATORDURATION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INDICATORDURATION.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INDICATORDURATIONS.fields_by_name['data'].message_type = _INDICATORDURATION
_ORDERSUMMARYNUM.fields_by_name['data'].message_type = _ORDERSUMMARY
_TRADEMESSAGELIST.fields_by_name['data'].message_type = _TRADEMESSAGEDATA
_TRADEMESSAGEDATA.fields_by_name['data'].message_type = _TRADEMESSAGE
_EXECRPTMESSAGELIST.fields_by_name['data'].message_type = _EXECRPTMESSAGEDATA
_EXECRPTMESSAGEDATA.fields_by_name['data'].message_type = _EXECRPTMESSAGE
_SYSMESSAGELIST.fields_by_name['data'].message_type = _SYSMESSAGEDATA
_SYSMESSAGEDATA.fields_by_name['data'].message_type = _SYSMESSAGE
_DEPTHSIGHTLIST.fields_by_name['bids'].message_type = _DEPTHSIGHT
_DEPTHSIGHTLIST.fields_by_name['asks'].message_type = _DEPTHSIGHT
_DEPTHSIGHTLISTOBJ.fields_by_name['data'].message_type = _DEPTHSIGHTLIST
DESCRIPTOR.message_types_by_name['RequestCommonParams'] = _REQUESTCOMMONPARAMS
DESCRIPTOR.message_types_by_name['Order'] = _ORDER
DESCRIPTOR.message_types_by_name['Orders'] = _ORDERS
DESCRIPTOR.message_types_by_name['OrdersPaged'] = _ORDERSPAGED
DESCRIPTOR.message_types_by_name['ExecRpt'] = _EXECRPT
DESCRIPTOR.message_types_by_name['ExecRpts'] = _EXECRPTS
DESCRIPTOR.message_types_by_name['Cash'] = _CASH
DESCRIPTOR.message_types_by_name['Cashes'] = _CASHES
DESCRIPTOR.message_types_by_name['Position'] = _POSITION
DESCRIPTOR.message_types_by_name['Settlement'] = _SETTLEMENT
DESCRIPTOR.message_types_by_name['SettlementItems'] = _SETTLEMENTITEMS
DESCRIPTOR.message_types_by_name['Stat'] = _STAT
DESCRIPTOR.message_types_by_name['StatItems'] = _STATITEMS
DESCRIPTOR.message_types_by_name['Asset'] = _ASSET
DESCRIPTOR.message_types_by_name['MarginAssets'] = _MARGINASSETS
DESCRIPTOR.message_types_by_name['GetMarginAssetsResp'] = _GETMARGINASSETSRESP
DESCRIPTOR.message_types_by_name['Commission'] = _COMMISSION
DESCRIPTOR.message_types_by_name['Positions'] = _POSITIONS
DESCRIPTOR.message_types_by_name['Account'] = _ACCOUNT
DESCRIPTOR.message_types_by_name['Accounts'] = _ACCOUNTS
DESCRIPTOR.message_types_by_name['AccountStatus'] = _ACCOUNTSTATUS
DESCRIPTOR.message_types_by_name['AccountStatuses'] = _ACCOUNTSTATUSES
DESCRIPTOR.message_types_by_name['AccountConnection'] = _ACCOUNTCONNECTION
DESCRIPTOR.message_types_by_name['AccountConnections'] = _ACCOUNTCONNECTIONS
DESCRIPTOR.message_types_by_name['ExchangeRates'] = _EXCHANGERATES
DESCRIPTOR.message_types_by_name['ExchangeRateList'] = _EXCHANGERATELIST
DESCRIPTOR.message_types_by_name['ExchangeRate'] = _EXCHANGERATE
DESCRIPTOR.message_types_by_name['CryptoCurrency'] = _CRYPTOCURRENCY
DESCRIPTOR.message_types_by_name['CryptoCurrencies'] = _CRYPTOCURRENCIES
DESCRIPTOR.message_types_by_name['Market'] = _MARKET
DESCRIPTOR.message_types_by_name['Markets'] = _MARKETS
DESCRIPTOR.message_types_by_name['ValidCoins'] = _VALIDCOINS
DESCRIPTOR.message_types_by_name['BacktestReq'] = _BACKTESTREQ
DESCRIPTOR.message_types_by_name['Progress'] = _PROGRESS
DESCRIPTOR.message_types_by_name['BacktestRes'] = _BACKTESTRES
DESCRIPTOR.message_types_by_name['Indicator'] = _INDICATOR
DESCRIPTOR.message_types_by_name['Indicators'] = _INDICATORS
DESCRIPTOR.message_types_by_name['IndicatorDuration'] = _INDICATORDURATION
DESCRIPTOR.message_types_by_name['IndicatorDurations'] = _INDICATORDURATIONS
DESCRIPTOR.message_types_by_name['OrderSummary'] = _ORDERSUMMARY
DESCRIPTOR.message_types_by_name['OrderSummaryNum'] = _ORDERSUMMARYNUM
DESCRIPTOR.message_types_by_name['TradeMessageList'] = _TRADEMESSAGELIST
DESCRIPTOR.message_types_by_name['TradeMessageData'] = _TRADEMESSAGEDATA
DESCRIPTOR.message_types_by_name['TradeMessage'] = _TRADEMESSAGE
DESCRIPTOR.message_types_by_name['ExecrptMessageList'] = _EXECRPTMESSAGELIST
DESCRIPTOR.message_types_by_name['ExecrptMessageData'] = _EXECRPTMESSAGEDATA
DESCRIPTOR.message_types_by_name['ExecrptMessage'] = _EXECRPTMESSAGE
DESCRIPTOR.message_types_by_name['SysMessageList'] = _SYSMESSAGELIST
DESCRIPTOR.message_types_by_name['SysMessageData'] = _SYSMESSAGEDATA
DESCRIPTOR.message_types_by_name['SysMessage'] = _SYSMESSAGE
DESCRIPTOR.message_types_by_name['Depthsight'] = _DEPTHSIGHT
DESCRIPTOR.message_types_by_name['DepthsightList'] = _DEPTHSIGHTLIST
DESCRIPTOR.message_types_by_name['DepthsightListObj'] = _DEPTHSIGHTLISTOBJ
DESCRIPTOR.enum_types_by_name['ExecType'] = _EXECTYPE
DESCRIPTOR.enum_types_by_name['OrderStatus'] = _ORDERSTATUS
DESCRIPTOR.enum_types_by_name['OrderRejectReason'] = _ORDERREJECTREASON
DESCRIPTOR.enum_types_by_name['OrderSide'] = _ORDERSIDE
DESCRIPTOR.enum_types_by_name['SecurityType'] = _SECURITYTYPE
DESCRIPTOR.enum_types_by_name['OrderType'] = _ORDERTYPE
DESCRIPTOR.enum_types_by_name['ExecInst'] = _EXECINST
DESCRIPTOR.enum_types_by_name['PositionSide'] = _POSITIONSIDE
DESCRIPTOR.enum_types_by_name['PositionEffect'] = _POSITIONEFFECT
DESCRIPTOR.enum_types_by_name['CashPositionChangeReason'] = _CASHPOSITIONCHANGEREASON
DESCRIPTOR.enum_types_by_name['OrderSrc'] = _ORDERSRC
DESCRIPTOR.enum_types_by_name['ErrorCodeFun'] = _ERRORCODEFUN
DESCRIPTOR.enum_types_by_name['AccountType'] = _ACCOUNTTYPE
DESCRIPTOR.enum_types_by_name['Model'] = _MODEL
DESCRIPTOR.enum_types_by_name['BacktestMode'] = _BACKTESTMODE
DESCRIPTOR.enum_types_by_name['SysMsgLevel'] = _SYSMSGLEVEL
DESCRIPTOR.enum_types_by_name['SysMsgType'] = _SYSMSGTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestCommonParams = _reflection.GeneratedProtocolMessageType('RequestCommonParams', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTCOMMONPARAMS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.RequestCommonParams)
  ))
_sym_db.RegisterMessage(RequestCommonParams)

Order = _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), dict(
  DESCRIPTOR = _ORDER,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Order)
  ))
_sym_db.RegisterMessage(Order)

Orders = _reflection.GeneratedProtocolMessageType('Orders', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _ORDERS_PROPERTIESENTRY,
    __module__ = 'core.api.account_pb2'
    # @@protoc_insertion_point(class_scope:core.api.Orders.PropertiesEntry)
    ))
  ,
  DESCRIPTOR = _ORDERS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Orders)
  ))
_sym_db.RegisterMessage(Orders)
_sym_db.RegisterMessage(Orders.PropertiesEntry)

OrdersPaged = _reflection.GeneratedProtocolMessageType('OrdersPaged', (_message.Message,), dict(
  DESCRIPTOR = _ORDERSPAGED,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.OrdersPaged)
  ))
_sym_db.RegisterMessage(OrdersPaged)

ExecRpt = _reflection.GeneratedProtocolMessageType('ExecRpt', (_message.Message,), dict(
  DESCRIPTOR = _EXECRPT,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ExecRpt)
  ))
_sym_db.RegisterMessage(ExecRpt)

ExecRpts = _reflection.GeneratedProtocolMessageType('ExecRpts', (_message.Message,), dict(
  DESCRIPTOR = _EXECRPTS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ExecRpts)
  ))
_sym_db.RegisterMessage(ExecRpts)

Cash = _reflection.GeneratedProtocolMessageType('Cash', (_message.Message,), dict(
  DESCRIPTOR = _CASH,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Cash)
  ))
_sym_db.RegisterMessage(Cash)

Cashes = _reflection.GeneratedProtocolMessageType('Cashes', (_message.Message,), dict(
  DESCRIPTOR = _CASHES,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Cashes)
  ))
_sym_db.RegisterMessage(Cashes)

Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), dict(
  DESCRIPTOR = _POSITION,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Position)
  ))
_sym_db.RegisterMessage(Position)

Settlement = _reflection.GeneratedProtocolMessageType('Settlement', (_message.Message,), dict(
  DESCRIPTOR = _SETTLEMENT,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Settlement)
  ))
_sym_db.RegisterMessage(Settlement)

SettlementItems = _reflection.GeneratedProtocolMessageType('SettlementItems', (_message.Message,), dict(
  DESCRIPTOR = _SETTLEMENTITEMS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.SettlementItems)
  ))
_sym_db.RegisterMessage(SettlementItems)

Stat = _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), dict(
  DESCRIPTOR = _STAT,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Stat)
  ))
_sym_db.RegisterMessage(Stat)

StatItems = _reflection.GeneratedProtocolMessageType('StatItems', (_message.Message,), dict(
  DESCRIPTOR = _STATITEMS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.StatItems)
  ))
_sym_db.RegisterMessage(StatItems)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), dict(
  DESCRIPTOR = _ASSET,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Asset)
  ))
_sym_db.RegisterMessage(Asset)

MarginAssets = _reflection.GeneratedProtocolMessageType('MarginAssets', (_message.Message,), dict(
  DESCRIPTOR = _MARGINASSETS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.MarginAssets)
  ))
_sym_db.RegisterMessage(MarginAssets)

GetMarginAssetsResp = _reflection.GeneratedProtocolMessageType('GetMarginAssetsResp', (_message.Message,), dict(
  DESCRIPTOR = _GETMARGINASSETSRESP,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.GetMarginAssetsResp)
  ))
_sym_db.RegisterMessage(GetMarginAssetsResp)

Commission = _reflection.GeneratedProtocolMessageType('Commission', (_message.Message,), dict(
  DESCRIPTOR = _COMMISSION,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Commission)
  ))
_sym_db.RegisterMessage(Commission)

Positions = _reflection.GeneratedProtocolMessageType('Positions', (_message.Message,), dict(
  DESCRIPTOR = _POSITIONS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Positions)
  ))
_sym_db.RegisterMessage(Positions)

Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNT,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Account)
  ))
_sym_db.RegisterMessage(Account)

Accounts = _reflection.GeneratedProtocolMessageType('Accounts', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Accounts)
  ))
_sym_db.RegisterMessage(Accounts)

AccountStatus = _reflection.GeneratedProtocolMessageType('AccountStatus', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTSTATUS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.AccountStatus)
  ))
_sym_db.RegisterMessage(AccountStatus)

AccountStatuses = _reflection.GeneratedProtocolMessageType('AccountStatuses', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTSTATUSES,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.AccountStatuses)
  ))
_sym_db.RegisterMessage(AccountStatuses)

AccountConnection = _reflection.GeneratedProtocolMessageType('AccountConnection', (_message.Message,), dict(

  ConnConfEntry = _reflection.GeneratedProtocolMessageType('ConnConfEntry', (_message.Message,), dict(
    DESCRIPTOR = _ACCOUNTCONNECTION_CONNCONFENTRY,
    __module__ = 'core.api.account_pb2'
    # @@protoc_insertion_point(class_scope:core.api.AccountConnection.ConnConfEntry)
    ))
  ,
  DESCRIPTOR = _ACCOUNTCONNECTION,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.AccountConnection)
  ))
_sym_db.RegisterMessage(AccountConnection)
_sym_db.RegisterMessage(AccountConnection.ConnConfEntry)

AccountConnections = _reflection.GeneratedProtocolMessageType('AccountConnections', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTCONNECTIONS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.AccountConnections)
  ))
_sym_db.RegisterMessage(AccountConnections)

ExchangeRates = _reflection.GeneratedProtocolMessageType('ExchangeRates', (_message.Message,), dict(

  DataEntry = _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), dict(
    DESCRIPTOR = _EXCHANGERATES_DATAENTRY,
    __module__ = 'core.api.account_pb2'
    # @@protoc_insertion_point(class_scope:core.api.ExchangeRates.DataEntry)
    ))
  ,
  DESCRIPTOR = _EXCHANGERATES,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ExchangeRates)
  ))
_sym_db.RegisterMessage(ExchangeRates)
_sym_db.RegisterMessage(ExchangeRates.DataEntry)

ExchangeRateList = _reflection.GeneratedProtocolMessageType('ExchangeRateList', (_message.Message,), dict(
  DESCRIPTOR = _EXCHANGERATELIST,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ExchangeRateList)
  ))
_sym_db.RegisterMessage(ExchangeRateList)

ExchangeRate = _reflection.GeneratedProtocolMessageType('ExchangeRate', (_message.Message,), dict(
  DESCRIPTOR = _EXCHANGERATE,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ExchangeRate)
  ))
_sym_db.RegisterMessage(ExchangeRate)

CryptoCurrency = _reflection.GeneratedProtocolMessageType('CryptoCurrency', (_message.Message,), dict(
  DESCRIPTOR = _CRYPTOCURRENCY,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.CryptoCurrency)
  ))
_sym_db.RegisterMessage(CryptoCurrency)

CryptoCurrencies = _reflection.GeneratedProtocolMessageType('CryptoCurrencies', (_message.Message,), dict(
  DESCRIPTOR = _CRYPTOCURRENCIES,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.CryptoCurrencies)
  ))
_sym_db.RegisterMessage(CryptoCurrencies)

Market = _reflection.GeneratedProtocolMessageType('Market', (_message.Message,), dict(
  DESCRIPTOR = _MARKET,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Market)
  ))
_sym_db.RegisterMessage(Market)

Markets = _reflection.GeneratedProtocolMessageType('Markets', (_message.Message,), dict(
  DESCRIPTOR = _MARKETS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Markets)
  ))
_sym_db.RegisterMessage(Markets)

ValidCoins = _reflection.GeneratedProtocolMessageType('ValidCoins', (_message.Message,), dict(
  DESCRIPTOR = _VALIDCOINS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ValidCoins)
  ))
_sym_db.RegisterMessage(ValidCoins)

BacktestReq = _reflection.GeneratedProtocolMessageType('BacktestReq', (_message.Message,), dict(
  DESCRIPTOR = _BACKTESTREQ,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.BacktestReq)
  ))
_sym_db.RegisterMessage(BacktestReq)

Progress = _reflection.GeneratedProtocolMessageType('Progress', (_message.Message,), dict(
  DESCRIPTOR = _PROGRESS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Progress)
  ))
_sym_db.RegisterMessage(Progress)

BacktestRes = _reflection.GeneratedProtocolMessageType('BacktestRes', (_message.Message,), dict(
  DESCRIPTOR = _BACKTESTRES,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.BacktestRes)
  ))
_sym_db.RegisterMessage(BacktestRes)

Indicator = _reflection.GeneratedProtocolMessageType('Indicator', (_message.Message,), dict(
  DESCRIPTOR = _INDICATOR,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Indicator)
  ))
_sym_db.RegisterMessage(Indicator)

Indicators = _reflection.GeneratedProtocolMessageType('Indicators', (_message.Message,), dict(
  DESCRIPTOR = _INDICATORS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Indicators)
  ))
_sym_db.RegisterMessage(Indicators)

IndicatorDuration = _reflection.GeneratedProtocolMessageType('IndicatorDuration', (_message.Message,), dict(
  DESCRIPTOR = _INDICATORDURATION,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.IndicatorDuration)
  ))
_sym_db.RegisterMessage(IndicatorDuration)

IndicatorDurations = _reflection.GeneratedProtocolMessageType('IndicatorDurations', (_message.Message,), dict(
  DESCRIPTOR = _INDICATORDURATIONS,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.IndicatorDurations)
  ))
_sym_db.RegisterMessage(IndicatorDurations)

OrderSummary = _reflection.GeneratedProtocolMessageType('OrderSummary', (_message.Message,), dict(
  DESCRIPTOR = _ORDERSUMMARY,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.OrderSummary)
  ))
_sym_db.RegisterMessage(OrderSummary)

OrderSummaryNum = _reflection.GeneratedProtocolMessageType('OrderSummaryNum', (_message.Message,), dict(
  DESCRIPTOR = _ORDERSUMMARYNUM,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.OrderSummaryNum)
  ))
_sym_db.RegisterMessage(OrderSummaryNum)

TradeMessageList = _reflection.GeneratedProtocolMessageType('TradeMessageList', (_message.Message,), dict(
  DESCRIPTOR = _TRADEMESSAGELIST,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.TradeMessageList)
  ))
_sym_db.RegisterMessage(TradeMessageList)

TradeMessageData = _reflection.GeneratedProtocolMessageType('TradeMessageData', (_message.Message,), dict(
  DESCRIPTOR = _TRADEMESSAGEDATA,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.TradeMessageData)
  ))
_sym_db.RegisterMessage(TradeMessageData)

TradeMessage = _reflection.GeneratedProtocolMessageType('TradeMessage', (_message.Message,), dict(
  DESCRIPTOR = _TRADEMESSAGE,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.TradeMessage)
  ))
_sym_db.RegisterMessage(TradeMessage)

ExecrptMessageList = _reflection.GeneratedProtocolMessageType('ExecrptMessageList', (_message.Message,), dict(
  DESCRIPTOR = _EXECRPTMESSAGELIST,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ExecrptMessageList)
  ))
_sym_db.RegisterMessage(ExecrptMessageList)

ExecrptMessageData = _reflection.GeneratedProtocolMessageType('ExecrptMessageData', (_message.Message,), dict(
  DESCRIPTOR = _EXECRPTMESSAGEDATA,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ExecrptMessageData)
  ))
_sym_db.RegisterMessage(ExecrptMessageData)

ExecrptMessage = _reflection.GeneratedProtocolMessageType('ExecrptMessage', (_message.Message,), dict(
  DESCRIPTOR = _EXECRPTMESSAGE,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ExecrptMessage)
  ))
_sym_db.RegisterMessage(ExecrptMessage)

SysMessageList = _reflection.GeneratedProtocolMessageType('SysMessageList', (_message.Message,), dict(
  DESCRIPTOR = _SYSMESSAGELIST,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.SysMessageList)
  ))
_sym_db.RegisterMessage(SysMessageList)

SysMessageData = _reflection.GeneratedProtocolMessageType('SysMessageData', (_message.Message,), dict(
  DESCRIPTOR = _SYSMESSAGEDATA,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.SysMessageData)
  ))
_sym_db.RegisterMessage(SysMessageData)

SysMessage = _reflection.GeneratedProtocolMessageType('SysMessage', (_message.Message,), dict(
  DESCRIPTOR = _SYSMESSAGE,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.SysMessage)
  ))
_sym_db.RegisterMessage(SysMessage)

Depthsight = _reflection.GeneratedProtocolMessageType('Depthsight', (_message.Message,), dict(
  DESCRIPTOR = _DEPTHSIGHT,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Depthsight)
  ))
_sym_db.RegisterMessage(Depthsight)

DepthsightList = _reflection.GeneratedProtocolMessageType('DepthsightList', (_message.Message,), dict(
  DESCRIPTOR = _DEPTHSIGHTLIST,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.DepthsightList)
  ))
_sym_db.RegisterMessage(DepthsightList)

DepthsightListObj = _reflection.GeneratedProtocolMessageType('DepthsightListObj', (_message.Message,), dict(
  DESCRIPTOR = _DEPTHSIGHTLISTOBJ,
  __module__ = 'core.api.account_pb2'
  # @@protoc_insertion_point(class_scope:core.api.DepthsightListObj)
  ))
_sym_db.RegisterMessage(DepthsightListObj)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n&com.nextfintech.tradingcenter.rpc.dataP\001Z(nextfin.com/nfplatform/core/api;core_api'))
_ORDER.fields_by_name['created_at'].has_options = True
_ORDER.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_ORDER.fields_by_name['updated_at'].has_options = True
_ORDER.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_ORDER.fields_by_name['settle_time'].has_options = True
_ORDER.fields_by_name['settle_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_ORDERS_PROPERTIESENTRY.has_options = True
_ORDERS_PROPERTIESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_EXECRPT.fields_by_name['created_at'].has_options = True
_EXECRPT.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_CASH.fields_by_name['created_at'].has_options = True
_CASH.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_CASH.fields_by_name['updated_at'].has_options = True
_CASH.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_POSITION.fields_by_name['created_at'].has_options = True
_POSITION.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_POSITION.fields_by_name['updated_at'].has_options = True
_POSITION.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_POSITION.fields_by_name['settle_at'].has_options = True
_POSITION.fields_by_name['settle_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_POSITION.fields_by_name['settle_time'].has_options = True
_POSITION.fields_by_name['settle_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_SETTLEMENT.fields_by_name['settled_time'].has_options = True
_SETTLEMENT.fields_by_name['settled_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_ACCOUNT.fields_by_name['account_id'].has_options = True
_ACCOUNT.fields_by_name['account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\txorm:\"pk\"'))
_ACCOUNT.fields_by_name['created_at'].has_options = True
_ACCOUNT.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))
_ACCOUNT.fields_by_name['updated_at'].has_options = True
_ACCOUNT.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"updated\"'))
_ACCOUNTCONNECTION_CONNCONFENTRY.has_options = True
_ACCOUNTCONNECTION_CONNCONFENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_ACCOUNTCONNECTION.fields_by_name['account'].has_options = True
_ACCOUNTCONNECTION.fields_by_name['account']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\016xorm:\"extends\"'))
_ACCOUNTCONNECTION.fields_by_name['conn_addr'].has_options = True
_ACCOUNTCONNECTION.fields_by_name['conn_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\013xorm:\"json\"'))
_ACCOUNTCONNECTION.fields_by_name['conn_conf'].has_options = True
_ACCOUNTCONNECTION.fields_by_name['conn_conf']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\013xorm:\"json\"'))
_EXCHANGERATES_DATAENTRY.has_options = True
_EXCHANGERATES_DATAENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_BACKTESTREQ.fields_by_name['start_time'].has_options = True
_BACKTESTREQ.fields_by_name['start_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_BACKTESTREQ.fields_by_name['end_time'].has_options = True
_BACKTESTREQ.fields_by_name['end_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_PROGRESS.fields_by_name['updated_at'].has_options = True
_PROGRESS.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_BACKTESTRES.fields_by_name['created_at'].has_options = True
_BACKTESTRES.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_BACKTESTRES.fields_by_name['updated_at'].has_options = True
_BACKTESTRES.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_INDICATOR.fields_by_name['created_at'].has_options = True
_INDICATOR.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_INDICATOR.fields_by_name['updated_at'].has_options = True
_INDICATOR.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_INDICATORDURATION.fields_by_name['positions'].has_options = True
_INDICATORDURATION.fields_by_name['positions']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\013xorm:\"json\"'))
_INDICATORDURATION.fields_by_name['duration'].has_options = True
_INDICATORDURATION.fields_by_name['duration']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\230\337\037\001'))
_INDICATORDURATION.fields_by_name['created_at'].has_options = True
_INDICATORDURATION.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_INDICATORDURATION.fields_by_name['updated_at'].has_options = True
_INDICATORDURATION.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_TRADEMESSAGE.fields_by_name['msg_id'].has_options = True
_TRADEMESSAGE.fields_by_name['msg_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\txorm:\"pk\"'))
_TRADEMESSAGE.fields_by_name['msg_time'].has_options = True
_TRADEMESSAGE.fields_by_name['msg_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\014xorm:\"index\"'))
_EXECRPTMESSAGE.fields_by_name['msg_id'].has_options = True
_EXECRPTMESSAGE.fields_by_name['msg_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\txorm:\"pk\"'))
_EXECRPTMESSAGE.fields_by_name['msg_time'].has_options = True
_EXECRPTMESSAGE.fields_by_name['msg_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\014xorm:\"index\"'))
_SYSMESSAGE.fields_by_name['msg_id'].has_options = True
_SYSMESSAGE.fields_by_name['msg_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\txorm:\"pk\"'))
_SYSMESSAGE.fields_by_name['msg_time'].has_options = True
_SYSMESSAGE.fields_by_name['msg_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\014xorm:\"index\"'))
# @@protoc_insertion_point(module_scope)
